pub fn casefold_char(c: char, mode: CaseFoldMode) -> charExpand description
Fold a single character using simple case folding.
Returns the folded character, or the input character unchanged if no folding applies.
pub fn casefold_char(c: char, mode: CaseFoldMode) -> charFold a single character using simple case folding.
Returns the folded character, or the input character unchanged if no folding applies.