pub enum IsNormalized {
Yes,
No,
Maybe,
}Expand description
Result of a quick-check test.
Variants
Yes
The string is definitely in the target normalization form.
No
The string is definitely not in the target normalization form.
Maybe
The string might not be normalized; a full check is required.