pub fn normalize_for_matching_utf16(
input: &str,
opts: &MatchingOptions,
) -> Vec<u16>Expand description
Normalize input for matching and encode the result as UTF-16.
Useful for interoperability with systems that use UTF-16 keyword tables.
pub fn normalize_for_matching_utf16(
input: &str,
opts: &MatchingOptions,
) -> Vec<u16>Normalize input for matching and encode the result as UTF-16.
Useful for interoperability with systems that use UTF-16 keyword tables.